Documentation
¶
Overview ¶
library provides an API for defining component catalogs that can be registered with modules.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ComponentID ¶
when adding components to raw nodes, there is no catalog just consistent component IDs, so we make this available
Types ¶
Click to show internal directories.
Click to hide internal directories.